package com.bolour.sample.eclipse.demo;

import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.core.runtime.IExtension;
import org.eclipse.core.runtime.IExtensionPoint;
import org.eclipse.core.runtime.IPluginRegistry;
import org.eclipse.core.runtime.Platform;

/**
 * Generic extension-processing class: for looping over all members
 * of all extensions of an extension-point, and calling a processing function on each.
 * 
 * @author Azad
 */
public class ProcessExtensions {

	/**
	 * Loop over all members of all extensions of an extension-point.
	 * 
	 * @param xpid The fully-qualified name of the extension-point.
	 * @param processor An object to call back on with each member of the extension-point.
	 */	
	public static void process(String xpid, IProcessMember processor) {

		IPluginRegistry registry = Platform.getPluginRegistry();
		IExtensionPoint extensionPoint =
			registry.getExtensionPoint(xpid);
		IExtension[] extensions = extensionPoint.getExtensions();
		
		// OUTER LOOP: For each extension ...
		for (int i = 0; i < extensions.length; i++) {			
			IExtension extension = extensions[i];
			// INNER LOOP: For each member of the extension ...
			IConfigurationElement[] elements = extension.getConfigurationElements();
			for (int j = 0; j < elements.length; j++) {
				IConfigurationElement element = elements[j];
				processor.process(extension, element);				
			}
		}
	}
}

	

